@@ -86,23 +86,35 @@ def get_client(ctx) -> PingVisionAPIClient:
     default=False,
     help="If set, poll until the submission is ready.",
 )
+@click.option("--insured-name")
 @click.option(
-    "--delegate-to-division",
-    metavar="DIVISION_SHORT_NAME",
-    help="Delegate to another organization. Provide the 'short name' of the division of the desired delegatee.  Requires the `delegate` permission.",
+    "--team",
+    "--team-uuid",
+    help="Team UUID to use for the submission. Optional unless you can access more than one team.",
 )
 @click.option(
+    "--delegate-to-company",
+    help="Delegate to another organization. Provide the company uuid, short_name, or id of the desired delegatee team.  Requires the `delegate` permission. If set but `delegate_to_team` is not set, the API will return an error if the company has multiple teams.",
+)
+@click.option(
+    "--delegate-to",
     "--delegate-to-team",
-    metavar="TEAM_NAME",
-    help="Delegate to another organization. Provide the 'name' of the desired delegatee team.  Requires the `delegate` permission.",
+    metavar="TEAM_UUID",
+    help="Delegate to another organization. Provide the 'uuid' of the desired delegatee team.  Requires the `delegate` permission. If set, `delegate_to_company` is required. Can be team uuid, or id",
 )
-def create(ctx, filename, poll_until_ready, delegate_to_division, delegate_to_team):
+def create(ctx, filename, poll_until_ready, team, insured_name, delegate_to_company, delegate_to):
+    """Create new submission from file(s)."""
+
     if isinstance(filename, pathlib.PosixPath):
         filename = [str(filename)]
 
     client = get_client(ctx)
     ret = client.create_submission(
-        filepaths=filename, delegate_to_division=delegate_to_division, delegate_to_team=delegate_to_team
+        filepaths=filename,
+        delegate_to_team=delegate_to,
+        delegate_to_company=delegate_to_company,
+        insured_name=insured_name,
+        team_uuid=team,
     )
     pingid = ret["id"]
     url = ret["url"]
@@ -112,9 +124,10 @@ def create(ctx, filename, poll_until_ready, delegate_to_division, delegate_to_te
 
     if poll_until_ready:
         while True:
-            ret = client.get_submission_detail(pingid=pingid)
+            ret = client.list_submission_activity(pingid=pingid)
+            ret = ret["results"][0] if ret["results"] else {}
             pprint.pprint(ret)
-            if ret["workflow_status"] == "completed":
+            if ret["workflow_status_name"] == "Completed":
                 break
             time.sleep(1.0)
 
@@ -123,12 +136,29 @@ def create(ctx, filename, poll_until_ready, delegate_to_division, delegate_to_te
 @click.pass_context
 @click.argument("pingid", type=str)
 def get(ctx, pingid):
+    """Get submission detail."""
     client = get_client(ctx)
 
     ret = client.get_submission_detail(pingid=pingid)
     pprint.pprint(ret)
 
 
+@cli.command()
+@click.pass_context
+def list_teams(ctx):
+    """List teams."""
+    client = get_client(ctx)
+
+    ret = client.list_teams()
+    if not ret:
+        print("No teams found.")
+        return
+
+    print(f"{'Team Name':<40}{'UUID':<36}")
+    for team in ret:
+        print(f"{team['team_name']:<40}{team['team_uuid']:<36}")
+
+
 @cli.command()
 @click.pass_context
 @click.option("--pretty", is_flag=True, default=False)
@@ -140,7 +170,7 @@ def get(ctx, pingid):
 @click.option("--search", help="Filter key fields by an arbitrary string")
 # @click.option("--organization__short_name")
 def activity(ctx, pretty, id, cursor_id, prev_cursor_id, page_size, fields, search):
-    """List submission activity, using /api/v1/submission"""
+    """List submission activity."""
     client = get_client(ctx)
 
     results = client.list_submission_activity(
@@ -152,7 +182,6 @@ def activity(ctx, pretty, id, cursor_id, prev_cursor_id, page_size, fields, sear
         search=search,
     )
     if pretty:
-        """print it like a table"""
         print(f"{'Activity ID':<36}{'Status':<30}{'Created':<20}")
         for activity in results["results"]:
             created_time_isoformatted = activity["created_time"]
@@ -161,10 +190,10 @@ def activity(ctx, pretty, id, cursor_id, prev_cursor_id, page_size, fields, sear
                 time.strptime(created_time_isoformatted, "%Y-%m-%dT%H:%M:%S.%fZ"),
             )
             print(
-                f"{activity['id'] or '*null*':<36}{activity['workflow_status__name'] or '*null*':<30}{created_time:<20}"
+                f"{activity['id'] or '*null*':<36}{activity['workflow_status_name'] or '*null*':<30}{created_time:<20}"
             )
             for doc in activity["documents"]:
-                print(f"  {doc['filename']:<40} {doc['processing_status']:<12} {doc['url']}")
+                print(f"  {doc['filename']:<40} {doc['url']}")
     else:
         pprint.pprint(results)
 
@@ -174,6 +203,7 @@ def activity(ctx, pretty, id, cursor_id, prev_cursor_id, page_size, fields, sear
 @click.argument("document_url")
 @click.option("-o", "--output", type=click.File("wb"))
 def download_document(ctx, document_url, output):
+    """Download document by document URL."""
     if not output:
         import urllib.parse, os
 
@@ -194,12 +224,12 @@ def download_document(ctx, document_url, output):
 
 @cli.command()
 @click.pass_context
-@click.option("-d", "--division-id", type=str, help="Division ID to filter by")
-def list_submission_statuses(ctx, division_id):
-    """List submission statuses"""
+@click.option("-d", "--division", type=str, help="Division UUID to filter by")
+def list_submission_statuses(ctx, division):
+    """List submission statuses."""
     client = get_client(ctx)
 
-    results = client.list_submission_statuses(division_id=division_id)
+    results = client.list_submission_statuses(division=division)
     if not results:
         print("No submission statuses found.")
         return
